@@ -182,7 +182,7 @@ class Block(Record):
     type = field_map("type")
     alive = field_map("alive")
 
-    def get_browseable_url(self):
+    def get_browseable_url(self) -> str:
         if "page" in self._type:
             return BASE_URL + self.id.replace("-", "")
         else:
