@@ -1,10 +1,10 @@
 import hashlib
 import json
 import re
-from typing import List, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 import uuid
 
-from requests import Session, HTTPError
+from requests import Response, Session, HTTPError
 from requests.cookies import cookiejar_from_dict
 from urllib.parse import urljoin
 from requests.adapters import HTTPAdapter
@@ -14,7 +14,6 @@ from getpass import getpass
 from .block import (
     Block,
     BLOCK_TYPES,
-    CollectionViewBlock,
     CollectionViewPageBlock,
     PageBlock,
 )
@@ -72,15 +71,15 @@ class NotionClient(object):
 
     def __init__(
         self,
-        token_v2=None,
-        monitor=False,
-        start_monitoring=False,
-        enable_caching=False,
-        cache_key=None,
-        email=None,
-        password=None,
-        client_specified_retry=None,
-    ):
+        token_v2:Optional[str]=None,
+        monitor:bool=False,
+        start_monitoring:bool=False,
+        enable_caching:bool=False,
+        cache_key:Optional[str]=None,
+        email:Optional[str]=None,
+        password:Optional[str]=None,
+        client_specified_retry:Optional[None]=None,
+    ) -> None:
         self.session = create_session(client_specified_retry)
         if token_v2:
             self.session.cookies = cookiejar_from_dict({"token_v2": token_v2})
@@ -187,7 +186,7 @@ class NotionClient(object):
     def get_record_data(self, table, id, force_refresh=False, limit=100):
         return self._store.get(table, id, force_refresh=force_refresh, limit=limit)
 
-    def get_block(self, url_or_id, force_refresh=False, limit=100):
+    def get_block(self, url_or_id: str, force_refresh:bool=False, limit:int=100) -> Union[TemplateBlock, CollectionRowBlock, Block, None]:
         """
         Retrieve an instance of a subclass of Block that maps to the block/page identified by the URL or ID passed in.
         """
@@ -273,7 +272,7 @@ class NotionClient(object):
         row_ids = [row.id for row in self.get_collection(collection_id).get_rows()]
         self._store.set_collection_rows(collection_id, row_ids)
 
-    def post(self, endpoint, data):
+    def post(self, endpoint: str, data: Any) -> Response:
         """
         All API requests on Notion.so are done as POSTs (except the websocket communications).
         """
@@ -350,21 +349,21 @@ class NotionClient(object):
 
     def search(
         self,
-        query="",
-        search_type="BlocksInSpace",
-        limit=100,
-        sort="Relevance",
-        source="quick_find",
-        isDeletedOnly=False,
-        excludeTemplates=False,
-        isNavigableOnly=False,
-        requireEditPermissions=False,
-        ancestors=[],
-        createdBy=[],
-        editedBy=[],
-        lastEditedTime={},
-        createdTime={},
-    ):
+        query:str="",
+        search_type:str="BlocksInSpace",
+        limit:int=100,
+        sort:str="Relevance",
+        source:str="quick_find",
+        isDeletedOnly:bool=False,
+        excludeTemplates:bool=False,
+        isNavigableOnly:bool=False,
+        requireEditPermissions:bool=False,
+        ancestors:List[str]=[],
+        createdBy:List[str]=[],
+        editedBy:List[str]=[],
+        lastEditedTime:Dict[str, Any]={},
+        createdTime:Dict[str, Any]={},
+    ) -> List[Union[TemplateBlock, CollectionRowBlock, Block]]:
         data = {
             "type": search_type,
             "query": query,
